==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/de_DE.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Ihre Einstellungen wurden aktualisiert.",
"Activity" => "Aktivität",
"A file or folder has been <strong>shared</strong>" => "Eine Datei oder Ordner wurde <strong>geteilt</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Eine neue Datei oder Ordner wurde im freigegebenen Ordner <strong>erstellt</strong>",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Eine neue Datei oder Ordner wurde im freigegebenen Ordner <strong>geändert</strong>",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Eine neue Datei oder Ordner wurde im freigegebenen Ordner <strong>gelöscht</strong>",
"You created %1\$s" => "Sie haben %1\$s erstellt",
"%2\$s created %1\$s" => "%2\$s erstellt %1\$s",
"You changed %1\$s" => "Sie haben %1\$s geändert",
"%2\$s changed %1\$s" => "%2\$s hat %1\$s geändert",
"You deleted %1\$s" => "Sie haben %1\$s gelöscht",
"%2\$s deleted %1\$s" => "%2\$s hat %1\$s gelöscht",
"You shared %1\$s with %2\$s" => "Sie teilen %1\$s mit %2\$s",
"You shared %1\$s with group %2\$s" => "Sie teilen %1\$s mit der Gruppe %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s teilt %1\$s mit Ihnen",
"You shared %1\$s via link" => "Sie haben %1\$s über einen Link freigegeben",
"Activity notification" => "Benachrichtigung über die Aktivitäten",
"All Activities" => "Alle Aktivitäten",
"Activities by you" => "Aktivitäten von Ihnen",
"Activities by others" => "Aktivitäten von Anderen",
"Shares" => "Freigaben",
"Files" => "Dateien",
"%s and %s" => "%s und %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s und <strong class=\"tooltip\" title=\"%s\">%n mehr</strong>","%s und <strong class=\"tooltip\" title=\"%s\">%n mehrere</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s und %n mehr","%s und %n mehrere"),
"Hello %s," => "Hallo %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Sie erhalten diese E-Mail, da in der letzten Stunde folgende Dinge auf %s geschehen sind",
"You are receiving this email because in the last day the following things happened at %s" => "Sie erhalten diese E-Mail, da am letzten Tag folgende Dinge auf %s geschehen sind",
"You are receiving this email because in the last week the following things happened at %s" => "Sie erhalten diese E-Mail, da in der letzten Woche folgende Dinge auf %s geschehen sind",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Sie werden hier eine Liste von Ereignissen sehen, sobald Sie Ihre %s nutzen.",
"No more events to load" => "Keine weiteren Ereignisse zum Laden",
"Enable RSS feed" => "RSS-Feed aktivieren",
"Notifications" => "Benachrichtigungen",
"Mail" => "Mail",
"Stream" => "Stream",
"You need to set up your email address before you can receive notification emails." => "Sie müssen ihre E-Mail Adresse zum Empfang von Erinnerungsmails einrichten.",
"Send emails:" => "Sende E-Mails:",
"Hourly" => "Stündlich",
"Daily" => "täglich",
"Weekly" => "wöchentlich",
"Activity feed" => "Feed der Aktivitäten",
"Personal activity feed for %s" => "Persönlicher Feed der Aktivitäten für %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/de_DE.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Ihre Einstellungen wurden aktualisiert.",
"Activity" => "Aktivität",
"A file or folder has been <strong>shared</strong>" => "Eine Datei oder Ordner wurde <strong>geteilt</strong>",
"A new file or folder has been <strong>created</strong>" => "Eine Datei oder Ordner wurde <strong>erstellt</strong>",
"A file or folder has been <strong>changed</strong>" => "Eine Datei oder Ordner wurde <strong>geändert</strong>",
"A file or folder has been <strong>deleted</strong>" => "Eine Datei oder Ordner wurde <strong>gelöscht</strong>",
"You created %1\$s" => "Sie haben %1\$s erstellt",
"%2\$s created %1\$s" => "%2\$s hat %1\$s erstellt",
"You changed %1\$s" => "Sie haben %1\$s geändert",
"%2\$s changed %1\$s" => "%2\$s hat %1\$s geändert",
"You deleted %1\$s" => "Sie haben %1\$s gelöscht",
"%2\$s deleted %1\$s" => "%2\$s hat %1\$s gelöscht",
"You shared %1\$s with %2\$s" => "Sie teilen %1\$s mit %2\$s",
"You shared %1\$s with group %2\$s" => "Sie teilen %1\$s mit der Gruppe %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s teilt %1\$s mit Ihnen",
"You shared %1\$s via link" => "Sie haben %1\$s über einen Link geteilt",
"Activity notification" => "Benachrichtigung über die Aktivitäten",
"All Activities" => "Alle Aktivitäten",
"Activities by you" => "Ihre Aktivitäten",
"Activities by others" => "Aktivitäten von Anderen",
"Shares" => "Geteiltes",
"Files" => "Dateien",
"%s and %s" => "%s und %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s und <strong class=\"tooltip\" title=\"%s\">%n mehr</strong>","%s und <strong class=\"tooltip\" title=\"%s\">%n mehrere</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s und %n weiteres","%s und %n weitere"),
"Hello %s," => "Hallo %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Sie erhalten diese E-Mail, da in der letzten Stunde folgende Dinge auf %s geschehen sind",
"You are receiving this email because in the last day the following things happened at %s" => "Sie erhalten diese E-Mail, da am letzten Tag folgende Dinge auf %s geschehen sind",
"You are receiving this email because in the last week the following things happened at %s" => "Sie erhalten diese E-Mail, da in der letzten Woche folgende Dinge auf %s geschehen sind",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Sie werden hier eine Liste von Ereignissen sehen, sobald Sie Ihre %s nutzen.",
"No more events to load" => "Keine weiteren Ereignisse zum Laden",
"Enable RSS feed" => "RSS-Feed aktivieren",
"Notifications" => "Benachrichtigungen",
"Mail" => "Mail",
"Stream" => "Stream",
"Notify about my own actions" => "Über eigene Aktivitäten benachrichtigen",
"You need to set up your email address before you can receive notification emails." => "Sie müssen ihre E-Mail Adresse zum Empfang von Erinnerungsmails einrichten.",
"Send emails:" => "Sende E-Mails:",
"Hourly" => "stündlich",
"Daily" => "täglich",
"Weekly" => "wöchentlich",
"Activity feed" => "Feed der Aktivitäten",
"Personal activity feed for %s" => "Persönlicher Feed der Aktivitäten für %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
